@@ -26,6 +26,9 @@ click_option_concurrency = click.option(
     type=int,
     help="Max number of concurrent web requests",
 )
+click_option_revision = click.option(
+    "--revision", help="Revision SHA or # (git, SVN, etc.)", required=False
+)
 
 
 @click.group()
@@ -88,11 +91,34 @@ def upload_bugreport(ctx: MemfaultCliClickContext, path: str):
     required=False,
     help="Required for firmware builds, see https://mflt.io/34PyNGQ",
 )
+@click_option_revision
 @click_option_concurrency
 @click_argument_path
 @pass_memfault_cli_context
 def upload_symbols(ctx: MemfaultCliClickContext, path: str, **kwargs):
-    """Upload symbols for a Firmware or Android build."""
+    """Upload symbols for a Firmware or Android build.
+
+    \b
+    Example Firmware Symbol Upload:
+    \b
+        $ memfault --email bot@example.com --password user-api-key \\
+                   --org acme-inc --project smart-sink \\
+            upload-symbols \\
+            --software-type stm32-fw \\
+            --software-version 1.0.0-alpha \\
+            --revision 89335ffade90ff7697e2ce5238bd4c68978b6d6e \\
+            build/symbols.elf
+
+    \b
+    Example Android Symbol Upload:
+    \b
+        $ memfault --email bot@example.com --password user-api-key \\
+                   --org acme-inc --project smart-sink
+            upload-symbols \\
+            out/target/product/generic/symbols
+
+        Reference: https://mflt.io/android-os-symbol-files
+    """
     ctx.obj.update(**kwargs)
 
     if os.path.isdir(path):
@@ -157,6 +183,7 @@ def upload_android_app_symbols(ctx: MemfaultCliClickContext, path: str, **kwargs
 @click.option("--hardware-version", required=True)
 @click.option("--software-type", required=True)
 @click.option("--software-version", required=True)
+@click_option_revision
 @click_argument_path
 @pass_memfault_cli_context
 def upload_ota_payload(ctx: MemfaultCliClickContext, path: str, **kwargs):
@@ -167,6 +194,20 @@ def upload_ota_payload(ctx: MemfaultCliClickContext, path: str, **kwargs):
 
     When deployed, this is the binary that will be returned from the Memfault /latest endpoint
     which can be used for an Over The Air (OTA) update.
+
+    \b
+    Example Firmware OTA Upload:
+    \b
+        $ memfault --email bot@example.com --password user-api-key \\
+                   --org acme-inc --project smart-sink \\
+            upload-ota-payload \\
+            --hardware-version mp \\
+            --software-type stm32-fw \\
+            --software-version 1.0.0-alpha \\
+            --revision 89335ffade90ff7697e2ce5238bd4c68978b6d6e \\
+            build/stm32-fw.bin
+
+        Reference: https://mflt.io/create-release
     """
     ctx.obj.update(**kwargs)
     _do_upload_or_raise(ctx, path, ReleaseArtifactUploader)
